import React, { useState, useRef, useEffect } from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { DatePicker, Select } from 'antd';
import moment from 'moment';
import PageTable from '@/components/PageTable';
import { getAccountLogList } from '@/services/accountLog'
import { getCooperativeList } from '@/services/cooperative';

const { RangePicker } = DatePicker;
const { Option } = Select;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm:ss') : '';
};


export default (props) => {
  const [start, setStartDate] = useState()
  const [end, setEndDate] = useState()
  const [cooperativeList, setCooperativeList] = useState([]);
  const handelChange = (date, dateStrings) => {
    setStartDate(dateStrings[0])
    setEndDate(dateStrings[1])
  }
  const ref = useRef();
  const Reset = () => {
    setStartDate()
    setEndDate()
    ref.current.reload();
  }
  useEffect(() => {
    getCooperativeList({ pageSize: 999 }).then((res) => {
      setCooperativeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
  }, [])
  const columns = [
    {
      title: '发生时间',
      dataIndex: 'createDate',
      key: 'createDate',
      search: false,
      render: (t) => formatterTime(t),
    },
    {
      title: '合作社',
      dataIndex: 'orgId',
      key: 'orgId',
      hideInTable: true,
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            {cooperativeList.map((item) => (
              <Option value={item.orgId} key={item.orgId}>
                {item.name}
              </Option>
            ))}
          </Select>
        )
      }
    },
    {
      title: '下单人',
      dataIndex: 'personName',
      key: 'personName',
      search: false
    },
    {
      title: '订单号',
      dataIndex: 'orderNo',
      key: 'orderNo',
    },
    {
      title: '类型',
      dataIndex: 'chargeType',
      key: 'chargeType',
      render: (_, record) => {
        return record.chargeType === 'order_pay'
          ? '订单收入'
          : record.chargeType === 'order_refund'
            ? '用户退款'
            : record.chargeType === 'withdraw'
              ? '提现' : ''
      },
      valueType: 'select',
      valueEnum: {
        'order_pay': { text: '订单收入' },
        'order_refund': { text: '用户退款' },
        'withdraw': { text: '提现' },
      },
    },
    //专门用来搜索
    {
      title: '发生时间',//结束时间
      dataIndex: 'createDate',
      key: 'createDate',
      hideInTable: true,
      render: (t, render) => formatterTime(render.createDate),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' onChange={handelChange} />
    },
    {
      title: '支付方式',
      dataIndex: 'payType',
      key: 'payType',
      search: false,
      render: (_, record) => {
        return record.chargeType === 'order_refund' ? '原路返回' :
          record.chargeType === 'withdraw' ? '银行卡转账' :
            record.payType === 'wx' ? '微信' :
              record.payType === 'zfb' ? '支付宝' : ''
      },
    },
    {
      title: '费用',
      dataIndex: 'money',
      key: 'money',
      render: (_, record) => {
        return record.chargeType === 'order_pay'
          ? '+' + (record.money / 100) : '-' + (record.money / 100)
      },
      search: false
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={ref}
        request={getAccountLogList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="logId"
        options={false}
        params={{ start, end }}
        onReset={Reset}
      />
    </PageHeaderWrapper>
  );
};
