import React, { useState, useRef } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import { Card, Row, Col } from 'antd';
import { useIntl } from 'umi';
import WCard from '@/components/WelcomeCard'
import { Swiper, SwiperSlide } from 'swiper/react';
import { Autoplay } from 'swiper';
import 'swiper/css';
import Bar from '@/components/Bar/index.jsx';
import Pie from '@/components/Pie';
import PieArea from '@/components/PieArea';
import { history } from 'umi';
import { getDispatchList } from '@/services/dispatch'
import './Welcome.less'
import { useEffect } from 'react';

const Welcome = () => {
  const intl = useIntl();
  const topData = [
    {
      icon: 'icon-icon',
      color: '#1cbbb4',
      title: '注册用户',
      value: 580239,
      percentage: 32.6
    },
    {
      icon: 'icon-show_gongsiguanli_fill',
      color: '#8dc63f',
      title: '合作社数',
      value: 2017,
      percentage: 5.6
    },
    {
      icon: 'icon-tuolaji',
      color: '#a5673f',
      title: '农用机数',
      value: 2000,
      percentage: 42.6
    },
    {
      icon: 'icon-dingdanguanli',
      color: '#8799a3',
      title: '订单数',
      value: 2075994,
      percentage: -1.6
    },
  ]
  const centerData = [
    {
      title: '预约订单',
      color: '#70d4d4',
      keyList: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月'],
      valueList: [320, 332, 301, 334, 390, 88, 320, 332, 301, 334, 390, 88]
    },
    {
      title: '完成订单',
      color: '#c3b6e6',
      keyList: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月'],
      valueList: [220, 182, 191, 234, 290, 256, 220, 182, 191, 234, 290, 356]
    }
  ]

  const [machineryStatus, setMachineryStatus] = useState([
    {
      color: '#70d4d4',
      keyList: ['预约', '作业', '闲置', '离线', '维修'],
      valueList: [350, 900, 650, 180, 380],
    }
  ])

  const [workData, setWorkData] = useState([
    { name: '收割机', value: 35 },
    { name: '播种机', value: 35 },
    { name: '农药机', value: 30 },
    { name: '其他', value: 180 },
  ]);
  const [workAreaData, setWorkAreaData] = useState([
    { name: '收割机', value: 350 },
    { name: '播种机', value: 900 },
    { name: '农药机', value: 650 },
    { name: '其他', value: 180 },
  ]);
  const [dispatchList, setDispatchList] = useState([])
  const goDispatch = (val) => {
    history.push(`../OrderManage/dispatch.jsx?id=${val.orderId}`);
  }
  useEffect(() => {
    getDispatchList({ isWarn: true, pageSize: 500 }).then((res) => {
      setDispatchList(res.records)
    })
  }, [])
  return (
    <PageContainer>
      <div className="welcome">
        <div className="head">
          <Row justify='space-between'>
            <Col flex='320px'>
              <WCard value={topData[0]} />
            </Col>
            <Col flex='320px'>
              <WCard value={topData[1]} />
            </Col>
            <Col flex='320px'>
              <WCard value={topData[2]} />
            </Col>
            <Col flex='320px'>
              <WCard value={topData[3]} />
            </Col>
          </Row>
        </div>

        <Row justify='space-between'>
          <Col span={16}>
            <Card style={{ marginTop: '32px' }}>
              <Bar h='500px' title='本年度预约订单数据概览' opt={centerData} />
            </Card>
          </Col>
          <Col span={7} >
            <Card title='待调度订单' style={{ marginTop: '32px', height: '548px' }} >
              {
                dispatchList.length <= 8 ?
                  <div style={{ height: '448px', width: '100%' }}>
                    {dispatchList.map(item =>
                      <div style={{ height: '60px' }} key={item.orderId} onClick={() => goDispatch(item)} >
                        {(item.personName || item.phone) + ' 于 ' + item.createDate + ' 下了一单请您尽快处理！'}
                      </div>
                    )}
                  </div> :
                  <Swiper
                    height={60}
                    style={{ height: '448px' }}
                    autoplay={{
                      delay: 1500,
                      disableOnInteraction: false,
                    }}
                    loop
                    loopAdditionalSlides={8}
                    modules={[Autoplay]}
                    direction="vertical"
                  >
                    {dispatchList.map((item) => (
                      <SwiperSlide key={item.orderId} onClick={() => goDispatch(item)}>
                        {(item.personName || item.phone) + ' 于 ' + item.createDate + ' 下了一单请您尽快处理！'}
                      </SwiperSlide>
                    ))}
                  </Swiper>
              }

            </Card>
          </Col>
        </Row>
        <div className='flex bottom'>
          <Card className='flex-1 card'>
            <Bar h='300px' title='农机状态统计' opt={machineryStatus} />
          </Card>
          <Card className='flex-1 card'>
            <PieArea opt={workAreaData} />
          </Card>
          <Card className='flex-1 card'>
            <Pie opt={workData} />
          </Card>
        </div>
      </div>
    </PageContainer>
  );
};

export default Welcome;
