import React, { useState, useRef } from 'react';
import { DatePicker } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import moment from 'moment';
import PageTable from '@/components/PageTable';
import { getPersonList } from '@/services/person';

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};

export default (props) => {
  const ref = useRef();

  const Reset = () => {
    ref.current.reload();
  };

  const columns = [
    {
      title: '昵称',
      dataIndex: 'nickName',
      key: 'nickName',
    },
    {
      title: '头像',
      dataIndex: 'avatar',
      key: 'avatar',
      render: (src) =>
        src != '-' && (
          <img src={src} alt="" style={{ width: '64px', height: '64px', borderRadius: '4px' }} />
        ),
      search: false,
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '注册时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t, render) => formatterTime(render.createDate),
      search: false,
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={ref}
        request={getPersonList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="personId"
        params={{ identity: 'farmer' }}
        onReset={Reset}
        options={false}
      />
    </PageHeaderWrapper>
  );
};
